==> peperit_2.0_estable.zip: themes/peperit/html_files/venta_lote.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 22/Mayo/2015
	// Versión 1.0 Formulario con los articulos del lote
	//---------------------------------------------------------------------------------------------------------
?>
<?php

$nombre_lote = Sections::getParam('nombre_lote', '');
$nombre_colegio = Sections::getParam('nombre_colegio', '');
$lote = new Lote($nombre_lote . '/' . $nombre_colegio);
/*echo("<pre>");
var_dump($lote);
echo("</pre>");*/
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
	<?=escupirMiga($lote->nombre);?>
</div>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="botones_cabecera">
        <a href="<?=Shop::$configuracion->url;?>cursos/<?=$nombre_lote;?>" class='boton' title="Volver"><?=traducir('Volver');?></a>
    </div>     
        <?php
        	//Formulario con el código de descuento
            new Widget($_WH->GW("lotes", "lote_pedir_cod_descuento"), $nombre_lote);
            $class = '';
            if($lote->trabaja_cantidades_pvp){
                $class = 'chequelibro';
        		
            }else{
                $class = 'mostrar_cantidades';
            }
            ?>
            <div class="<?=$class;?>">
            <?php
        	//datos del lote
            new Widget($_WH->GW("lotes", "venta_lote"), new OpcionesWidget(array('objeto_lote' => $lote, 'fichero' => 'linea_venta_lote')));
        ?>
    </div>

</div>

==> peperit_2.1.02_estable.zip: themes/peperit/html_files/venta_lote.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 22/Mayo/2015
	// Versión 1.0 Formulario con los articulos del lote
	//---------------------------------------------------------------------------------------------------------
?>
<?php

$nombre_colegio = Sections::getParam('nombre_colegio', '');
$nombre_curso = Sections::getParam('nombre_curso', '');

//Pedro 03/Septiembre/2020 ==> OJO que puede que no nos pasen nombre del curso y sea un lote entero:
$nombre_lote = $nombre_colegio . (($nombre_curso != '')? '/' : '') . $nombre_curso;
$lote = new Lote($nombre_lote);

?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
	<?=escupirMiga($lote->nombre);?>
</div>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="botones_cabecera">
<?php
		//Pedro 03/Septiembre/2020 ==> Es posible que estemos en un lote que no se compone con "colegio/curso"
		$urlLote = Shop::$configuracion->url . 'cursos/' . corregir_url($nombre_lote);
		if (strpos($nombre_lote, '/') === false) {
			$urlLote = Shop::$configuracion->url . 'colegios';
		}
?>
        <a href="<?=$urlLote;?>" class='boton' title="Volver"><?=traducir('Volver');?></a>
    </div>     
        <?php
        	//Formulario con el código de descuento
            new Widget($_WH->GW("lotes", "lote_pedir_cod_descuento"), $nombre_lote);
            $class = '';
            if($lote->trabaja_cantidades_pvp){
                $class = 'chequelibro';
        		
            }else{
                $class = 'mostrar_cantidades';
            }
            ?>
            <div class="<?=$class;?>">
            <?php
        	//datos del lote
            new Widget($_WH->GW("lotes", "venta_lote"), new OpcionesWidget(array('objeto_lote' => $lote, 'fichero' => 'linea_venta_lote')));
        ?>
    </div>

</div>
